@@ -1,5 +1,6 @@
 from dataclasses import dataclass, field
 from enum import Enum, unique
+from typing import Optional
 
 from notification_server_connector.utils.current_timestamp import get_current_timestamp_ms
 
@@ -18,6 +19,6 @@ class Notification:
     portal_member_id: int
     title: str
     message: str
-    visit_url: str
+    parent_id: Optional[int] = None
     notification_receivers: list[int] = field(default_factory=list)
     created_at: int = field(default_factory=get_current_timestamp_ms)
